@@ -4,34 +4,10 @@ import os
 
 import pytest
 
-from utils import run, dbtest, set_expanded_output, is_expanded_output
+from utils import run, dbtest, set_expanded_output, is_expanded_output, assert_result_equal
 from sqlite3 import OperationalError, ProgrammingError
 
 
-def assert_result_equal(
-    result,
-    title=None,
-    rows=None,
-    headers=None,
-    status=None,
-    auto_status=True,
-    assert_contains=False,
-):
-    """Assert that an sqlexecute.run() result matches the expected values."""
-    if status is None and auto_status and rows:
-        status = "{} row{} in set".format(len(rows), "s" if len(rows) > 1 else "")
-    fields = {"title": title, "rows": rows, "headers": headers, "status": status}
-
-    if assert_contains:
-        # Do a loose match on the results using the *in* operator.
-        for key, field in fields.items():
-            if field:
-                assert field in result[0][key]
-    else:
-        # Do an exact match on the fields.
-        assert result == [fields]
-
-
 @dbtest
 def test_conn(executor):
     run(executor, """create table test(a text)""")
@@ -274,8 +250,7 @@ def test_favorite_query_multiple_statement(executor):
 
     results = run(
         executor,
-        "\\fs test-ad select * from test where a like 'a%'; "
-        "select * from test where a like 'd%'",
+        "\\fs test-ad select * from test where a like 'a%'; " "select * from test where a like 'd%'",
     )
     assert_result_equal(results, status="Saved.")
 
@@ -346,9 +321,7 @@ def test_cd_command_without_a_folder_name(executor):
 @dbtest
 def test_system_command_not_found(executor):
     results = run(executor, "system xyz")
-    assert_result_equal(
-        results, status="OSError: No such file or directory", assert_contains=True
-    )
+    assert_result_equal(results, status="OSError: No such file or directory", assert_contains=True)
 
 
 @dbtest
